@@ -1,42 +1,42 @@
 $VAR1 = {
-          'scriptAlias' => 'cgi-bin',
-          'admin' => {
-                       'password' => 'testpass',
-                       'firstname' => 'Dirk',
-                       'name' => 'Lindner',
-                       'email' => 'dirk.lze@gmail.com'
-                     },
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
           'language' => 'en',
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'floodtime' => 10,
           'config' => '/var/www/cgi-bin/config/settings.pl',
-          'version' => '0.76',
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'scriptAlias' => 'cgi-bin',
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
           'cgi' => {
+                     'DocumentRoot' => '/var/www/htdocs',
                      'cookiePath' => '/',
-                     'alias' => 'cgi-bin',
-                     'serverName' => 'http://localhost',
                      'title' => 'MySQL::Admin',
                      'bin' => '/var/www/cgi-bin',
                      'expires' => '+1y',
-                     'DocumentRoot' => '/var/www/htdocs',
+                     'alias' => 'cgi-bin',
+                     'serverName' => 'http://localhost',
                      'style' => 'mysql'
                    },
+          'floodtime' => 10,
+          'admin' => {
+                       'name' => 'Lindner',
+                       'email' => 'dirk.lze@gmail.com',
+                       'firstname' => 'Dirk',
+                       'password' => 'testpass'
+                     },
+          'version' => '0.77',
           'files' => {
-                       'chmod' => '0755',
                        'group' => 'www-data',
+                       'chmod' => '0755',
                        'owner' => 'www-data'
                      },
           'database' => {
                           'password' => 'keinz',
-                          'CurrentHost' => 'localhost',
+                          'host' => 'localhost',
                           'name' => 'LZE',
-                          'CurrentPass' => 'keinz',
-                          'CurrentDb' => 'LZE',
-                          'CurrentUser' => 'root',
                           'user' => 'root',
-                          'host' => 'localhost'
-                        }
+                          'CurrentPass' => 'keinz',
+                          'CurrentUser' => 'root',
+                          'CurrentHost' => 'localhost',
+                          'CurrentDb' => 'LZE'
+                        },
+          'session' => '/var/www/cgi-bin/config/session.pl'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
