@@ -153,13 +153,36 @@ function markTables(bool){
        visible (bool ? 'umarkAll2' : 'markAll2' );
        hide (bool ? 'markAll2' : 'umarkAll2' );
 }
-var nCurrentShown;
 
+var nCurrentShown;
 function DisplayTable(id){
         hide( nCurrentShown);
         visible(id);
         nCurrentShown = id;
 }
+var aCurrentShown = new Array();
+function DisplayTables(i,id){
+        hide( aCurrentShown[i] );
+	aCurrentShown[i] = id;
+        visible(id);
+}
+function setIndexType (type){
+  if(type == 'FOREIGN KEY')
+      hideForeign( false );
+  else
+     hideForeign( true );
+}
+function hideForeign(bHide){
+       var body  = document.getElementsByTagName("body")[0];
+       var node = body.getElementsByTagName("td");
+       for(var i=0,j=node.length; i<j; i++){
+	var a =  node[i].classList ;
+         for(var k=0,l=node.length; k<l; k++){
+	    if(a[k] == 'foreign')
+	      node[i].style.display  =  bHide ? 'none' :'';
+	 }
+       }
+}
 function DisplayKeyWords(b){
   if(b){
     $('akeywods').className = 'currentLink';
@@ -208,17 +231,17 @@ function setAction(n){
 var tmpTxt;
 var tmpID;
 function showPopup(id,hideCloseButton){
-	visible('popup');
-	if(hideCloseButton)
-	  hide('closeButton');
-	else
-	  visible('closeButton');
-	tmpTxt = getText(id);
-	tmpID = id;popupTitle
-	setText(id,'');
-	setText('popupTitle',translate(id));
-        setText('popupContent',tmpTxt);
-	evalId(id);
+    visible('popup');
+    if(hideCloseButton)
+      hide('closeButton');
+    else
+      visible('closeButton');
+    tmpTxt = getText(id);
+    tmpID = id;popupTitle
+    setText(id,'');
+    setText('popupTitle',translate(id));
+    setText('popupContent',tmpTxt);
+    evalId(id);
 }
 function closePopup(){
     setText(tmpID,tmpTxt);	
