@@ -31,8 +31,8 @@ use DBI::Library qw(:all $m_dbh $m_dsn);
         qw(getIndex CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember right checkPass checkSession setSid getName checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue)
     ],
 );
-$DBI::Library::Database::VERSION = '0.76';
-$m_nSecs                         = 10;
+$DBI::Library::Database::VERSION = '0.77';
+$m_nSecs                         =  10;
 
 =head1 NAME
 
@@ -81,7 +81,7 @@ sub getName
 
 =head2 setSid
 
-$m_sSidid = $m_oDatabase->setSid(name,pass);
+      $sid = $m_oDatabase->setSid( name, pass );
 
 =cut
 
@@ -133,6 +133,8 @@ sub checkSession
 
 =head2 checkPass()
 
+
+
 =cut
 
 sub checkPass
@@ -168,7 +170,7 @@ sub right
 
 =head2 userright()
 
-      userright(user);
+      userright( user );
 
 =cut
 
@@ -186,7 +188,7 @@ sub userright
 
 =head2 topicright()
 
-      topicright(id);
+      topicright( id );
 
 =cut
 
@@ -214,10 +216,10 @@ sub catright
     my $cat = $p[0];
     my @select = split /\|/, $cat;
     my %sel;
-    $sel{$_} = 1 foreach @select;
+    $sel{$_}   = 1 foreach @select;
     my @cats   = $self->fetch_AoH('SELECT * FROM cats');
     my $nRight = 0;
-    for (my $i = 0; $i <= $#cats; $i++) {
+    for( my $i = 0; $i <= $#cats; $i++ ){
         $nRight = $cats[$i]->{right} if ($sel{$cats[$i]->{name}} && $cats[$i]->{right} > $nRight);
     }
     return $nRight;
@@ -227,9 +229,6 @@ sub catright
 
       isMember($m_sUser);
 
-checkt ob es den user bereits gibt.
-
-
 =cut
 
 sub isMember
@@ -249,9 +248,7 @@ sub isMember
 
 =head2 hasAcount
 
-      hasAcount($email)
-
-checkt ob es die  email Adresse bereits gibt.
+      bool hasAcount( $email )
 
 =cut
 
@@ -272,7 +269,7 @@ sub hasAcount
 
 =head2 addUser
 
-      $m_oDatabase->addUser(user, pass);
+      $m_oDatabase->addUser(user, pass,mail);
 
 =cut
 
@@ -281,12 +278,12 @@ sub addUser
     my ($self, @p) = getSelf(@_);
     my $newuser = $p[0];
     my $newpass = $p[1];
+    my $mail    = $p[2];
     use MD5;
-    my $md5 = new MD5;
+    my $md5     = new MD5;
     $md5->add($newuser);
     $md5->add($newpass);
     my $fingerprint = $md5->hexdigest();
-    my $mail        = $p[2];
     my $sql_addUser = q/insert into users (user,pass,email,`right`,cats) values(?,?,?,1,'news|member')/;
     my $sth         = $m_dbh->prepare($sql_addUser);
     my $anzahl      = $sth->execute($newuser, $fingerprint, $mail) or warn $m_dbh->errstr;
@@ -294,7 +291,6 @@ sub addUser
     return 1 if ($anzahl + 0 == 1);
 }
 
-
 =head2 serverName()
 
 set serverName.
@@ -304,8 +300,11 @@ set serverName.
 sub serverName
 {
     my ($self, @p) = getSelf(@_);
-    if (defined $p[0]) {$m_sServerName = $p[0];}
-    else               {return $m_sServerName;}
+    if (defined $p[0]){
+      $m_sServerName = $p[0];
+    }else{
+      return $m_sServerName;
+    }
 }
 
 =head2 floodtime()
@@ -317,18 +316,22 @@ set floodtime.
 sub floodtime
 {
     my ($self, @p) = getSelf(@_);
-    if (defined $p[0]) {$m_nSecs = $p[0];}
-    else               {return $m_nSecs;}
+    if (defined $p[0]){
+      $m_nSecs = $p[0];
+    }else{
+      return $m_nSecs;
+    }
 }
 
 =head2 checkFlood
 
 checked wann die letzte aktion der ip adresse war und
+
 erlaubt sie nur wenn midestens time zeit zur letzen aktion vergangen ist.
 
 checkFlood(ip,optionaler abstand in sekunden )
 
-        checkFlood(remote_addr());
+checkFlood( remote_addr() );
 
 =cut
 
@@ -357,8 +360,7 @@ sub checkFlood
 
 =head2 GetAutoIncrementValue()
 
-
-       GetAutoIncrementValue(table)
+    GetAutoIncrementValue(table)
 
 =cut
 
@@ -384,23 +386,22 @@ sub GetPrimaryKey
 {
     my ($self, @p) = getSelf(@_);
     my $tbl = $p[0];
-    if (defined $tbl) {
+    if( defined $tbl ) {
         $tbl = $m_dbh->quote_identifier($tbl);
         my @caption = $self->fetch_AoH("show columns from $tbl");
         my @return;
         for (my $j = 0; $j <= $#caption; $j++) {
             push @return, $caption[$j]->{'Field'} if ($caption[$j]->{'Key'} eq 'PRI');
         }
-        push @return, $caption[0]->{'Field'} if ($#caption eq 0);
+        push @return, $caption[0]->{'Field'} if $#caption eq 0;
         return @return;
-    } else {
+    }else{
         return 0;
     }
 }
 
 =head2 getIndex()
 
-
 =cut
 
 sub getIndex
@@ -412,26 +413,73 @@ sub getIndex
 	my $hr =   $self->fetch_hashref("SHOW CREATE TABLE $tbl");
 	my @return;
 	foreach my $line ( split /\n/,$hr->{'Create Table'}){
-	    if($line =~/(FULLTEXT KEY|UNIQUE KEY|KEY) `(.+)` \((.+)\)/){
+	  if($line =~/(PRIMARY KEY|FOREIGN KEY|FULLTEXT KEY|UNIQUE KEY|KEY) (`([^`]+)`)? ?(\(([^)]+)\))?/){
 	      my $type = $1;
-	      my $name = $2;
-	      push @return, {
-		  field =>  /^`(.+)`$/,
-		  name  => $name,
-		  type  => $type,
-	      } for split /,/ , $3;
+	      my $name = $type eq 'FOREIGN KEY' ? $return[$#return]->{field} : $2;  
+	      delete $return[$#return];
+	      my $sfields = $5;
+	      my @fields;
+	      push @fields, /`([^`]+)`/ for split ',' , $5;
+	      if($line =~/REFERENCES `([^`]+)` \(([^)]+)\)/){
+		my $table= $1;     
+		my @references;
+		push @references, /`([^`]+)`/ for split ',' , $2;
+		push @return, {
+		    field         =>  /`([^`]+)`/,
+		    foreignTable  =>  $table,
+		    foreignFields =>  [@fields],
+		    foreignReferences =>  [@references],
+		    name  => $name,
+		    type  => $type,
+		    ondelete => $line =~/ON DELETE CASCADE/ ? 'CASCADE' :$line =~/ON DELETE SET DEFAULT/ ? 'SET DEFAULT' :'',
+		    onupdate => $line =~/ON UPDATE CASCADE/ ? 'CASCADE' :$line =~/ON UPDATE SET DEFAULT/ ? 'SET DEFAULT' :'',
+		} for split ',' , $sfields;
+		}else{
+		  push @return, {
+		      field =>  /`([^`]+)`/,
+		      name  => $name,
+		      type  => $type,
+		  } for split ',' , $5;
+		}
 	    }
 	}
 	return @return;
     }
 }
 
-   
+=head2 getConstraintKeys()
+
+=cut
+
+sub getConstraintKeys
+{
+    my ($self, @p) = getSelf(@_);
+    my $tbl = $p[0];
+    my $key = $p[1];
+    my @return;
+    if (defined $tbl){
+	$tbl = $m_dbh->quote_identifier($tbl);
+        my $hr =   $self->fetch_hashref("SHOW CREATE TABLE $tbl");
+  	foreach my $line ( split /\n/,$hr->{'Create Table'}){
+	  my %keys;
+	  if($line =~/CONSTRAINT `([^`]+)` FOREIGN KEY \(([^)]+)\)/){
+	    my $i = 0;
+	    for( split ',' ,$2){
+	      /`([^`]+)`/ ;
+	      $keys{$1} = 1;
+	    }
+	    push @return, $1 if($keys{$key} and $return[$#return-1] ne $1 );
+	  }
+	}
+	return @return;
+    }
+}
+
 =head2 GetAutoIncrement()
 
-       liefert die auto_increment zeile zurueck
+    returns  the auto_increment Column.
 
-       GetAutoIncrement(table)
+    GetAutoIncrement(table)
 
 =cut
 
@@ -468,7 +516,7 @@ sub fetch_string
 
 =head2 GetDataBases()
 
-     Gibt eine auswahl liste der Datenabanken zurueck
+     returns a <select> list with the Databases.
 
 =cut
 
@@ -483,8 +531,8 @@ sub GetDataBases
     $return .=
       $_ eq $m_sCurrentDb
       ? qq|<option  value="$_"  selected="selected" >$_(| . $self->TableCount4Db($_) . q|)</option>|
-      : qq|<option  value="$_">$_(| . $self->TableCount4Db($_) . q|)</option>|
-      foreach @dbs;
+      : qq|<option  value="$_">$_(| . $self->TableCount4Db($_) . q|)</option>| foreach @dbs;
+
     $return .= '</select>';
     return $return;
 }
@@ -506,9 +554,9 @@ sub TableCount4Db
 
 =head2 GetCharacterSet()
 
-        gibt das Charset zu coalation zurueck.
+    gibt das Charset zu coalation zurueck.
 
-        GetCharacterSet(coalation);
+    GetCharacterSet(coalation);
 
 =cut
 
@@ -526,9 +574,9 @@ sub GetCharacterSet
 
 =head2 GetEngines()
 
-        gibt die verfuegbaren Engines zurueck.
+    gibt die verfuegbaren Engines zurueck.
 
-        GetEngines(tabelle);
+    GetEngines(tabelle);
 
 =cut
 
@@ -555,7 +603,7 @@ sub GetEngines
 
 =head2 GetEngineForRow()
 
-        GetEngineForRow(tabelle, zeile);
+    GetEngineForRow(tabelle, zeile);
 
 =cut
 
@@ -564,7 +612,7 @@ sub GetEngineForRow
     my ($self, @p) = getSelf(@_);
     my $tbl  = shift @p;
     my $name = shift @p;
-    if (defined $tbl && defined $name) {
+    if (defined $tbl && defined $name){
         my @co       = $self->fetch_array('SHOW ENGINES');
         my @EINGINES = $self->fetch_AoH('SHOW TABLE STATUS where `Name` = ?  ', $tbl);
         my $return   = qq|<select class="editTable" name="$name">|;
@@ -575,16 +623,16 @@ sub GetEngineForRow
           foreach @EINGINES;
         $return .= '</select>';
         return $return;
-    } else {
+    }else{
         return 0;
     }
 }
 
 =head2 GetNull()
 
-        gibt die NULL(NULL | not NULL) auswahlliste zurueck
+    gibt die NULL( NULL | not NULL ) auswahlliste zurueck
 
-        GetNull(selected extra, slect_name);
+    GetNull( selected extra, slect_name );
 
 =cut
 
@@ -595,7 +643,7 @@ sub GetNull
     my $name = shift @p;
     if (defined $null && defined $name) {
         my $return = qq|<select class="editTable" name="$name">|;
-        $return .= qq|<option  value="not NULL">not NULL</option>|;
+        $return .= qq|<option value="not NULL">not NULL</option>|;
         $return .=
           $null eq 'YES'
           ? qq|<option  value="NULL" selected="selected">NULL</option>|
@@ -622,8 +670,8 @@ sub GetExtra
     my $name     = shift @p;
     if (defined $selected && defined $name) {
         my $return = qq|<select class="editTable" name="$name">|;
-        $return .= '<option value=""></option>';
-        $return .=
+        $return   .= '<option value=""></option>';
+        $return   .=
           $selected eq "auto_increment"
           ? q|<option  value="auto_increment" selected="selected">auto_increment</option>|
           : q|<option value="auto_increment">auto_increment</option>|;
@@ -660,7 +708,7 @@ sub GetColumnCollation
               $_->{Collation} eq $col->{Collation}
               ? qq|<option  value="$_->{Collation}"  selected="selected" >$_->{Collation}</option>|
               : qq|<option  value="$_->{Collation}">$_->{Collation}</option>|
-              foreach @collation;
+            foreach @collation;
         }
         $return .= '</select>';
         return $return;
@@ -671,7 +719,7 @@ sub GetColumnCollation
 
 =head2 GetCollation()
 
-        $sel = GetCollation(name);
+    $sel = GetCollation( name, selected );
 
 =cut
 
@@ -689,14 +737,14 @@ sub GetCollation
         }
     }
     my $return = qq|<select class="editTable" name="$name" style="width:100px;"><option></option>|;
-    $return .= qq|<option  value="$_->{Collation}"| . ($selected eq $_->{Collation} ? 'selected="selected"' : '') . qq|>$_->{Collation}</option>| foreach @collation;
+    $return .= qq|<option  value="$_->{Collation}"|.( $selected eq $_->{Collation} ? 'selected="selected"' : '').qq|>$_->{Collation}</option>| foreach @collation;
     $return .= '</select>';
     return $return;
 }
 
 =head2 GetCharset()
 
-        $sel = GetCharset(name,table);
+    $sel = GetCharset(name,selected table);
 
 =cut
 
@@ -721,7 +769,7 @@ sub GetCharset
 
 =head2 GetAttrs
 
-       $sel = GetAttrs($tbl, $field, $m_hUniqueAttrs );
+       $sel = GetAttrs($tbl, $field, $name );
 
 =cut
 
@@ -748,30 +796,28 @@ sub GetAttrs
              ? 'selected="selected"'
              : ''
           )
-          . q|>UNSIGNED ZEROFILL</option>
-    <option  value="ON UPDATE CURRENT_TIMESTAMP"  |
+          . q|>UNSIGNED ZEROFILL</option><option  value="ON UPDATE CURRENT_TIMESTAMP"  |
           . (
              $hr->{'Create Table'} =~ /$select[^,]+on update CURRENT_TIMESTAMP/
              ? 'selected="selected"'
              : ''
           )
-          . q|>ON UPDATE CURRENT_TIMESTAMP</option>
-    </select>|;
+          . q|>ON UPDATE CURRENT_TIMESTAMP</option></select>|;
         return $return;
     } else {
         return qq(
-    <select class="editTable" name="$name" style="width:100px;">
-    <option ></option>
-    <option  value="UNSIGNED" ) .                    ($select eq 'UNSIGNED'                    ? 'selected="selected"' : '') . q(>UNSIGNED</option>
-    <option  value="UNSIGNED ZEROFILL" ) .           ($select eq 'UNSIGNED ZEROFILL'           ? 'selected="selected"' : '') . q(>UNSIGNED ZEROFILL</option>
-    <option  value="ON UPDATE CURRENT_TIMESTAMP" ) . ($select eq 'ON UPDATE CURRENT_TIMESTAMP' ? 'selected="selected"' : '') . q(>ON UPDATE CURRENT_TIMESTAMP</option>
-    </select>);
+	  <select class="editTable" name="$name" style="width:100px;">
+	  <option ></option>
+	  <option  value="UNSIGNED" ) .                    ( $select eq 'UNSIGNED'                    ? 'selected="selected"' : '') . q(>UNSIGNED</option>
+	  <option  value="UNSIGNED ZEROFILL" ) .           ( $select eq 'UNSIGNED ZEROFILL'           ? 'selected="selected"' : '') . q(>UNSIGNED ZEROFILL</option>
+	  <option  value="ON UPDATE CURRENT_TIMESTAMP" ) . ( $select eq 'ON UPDATE CURRENT_TIMESTAMP' ? 'selected="selected"' : '') . q(>ON UPDATE CURRENT_TIMESTAMP</option>
+	  </select>);
     }
 }
 
 =head2 GetColumns
 
-       $sel = GetColumns($tbl ,$name,$selected);
+    $sel = GetColumns($tbl , $name, $selected);
 
 =cut
 
@@ -791,7 +837,7 @@ sub GetColumns
 
 =head2 getSelf()
 
-see HTML::Menu::TreeView::getSelf
+    getSelf or CGI
 
 =cut
 
@@ -847,7 +893,7 @@ sub fetch
 =head1 SEE ALSO
 
 L<MySQL::Admin::GUI> L<DBI> L<DBI::Library>
-"
+
 =head1 AUTHOR
 
 Dirk Lindner <lze@cpan.org>
